"""
Fedora OpenId backend, docs at:
    http://psa.matiasaguirre.net/docs/backends/fedora.html
"""
from social.backends.open_id import OpenIdAuth


class FedoraOpenId(OpenIdAuth):
    name = 'fedora'
    URL = 'https://id.fedoraproject.org'
    USERNAME_KEY = 'nickname'

    def get_user_details(self, response):
        """
        Override the email because the @fedoraproject.org alias is more
        significant than the OpenID-provided email address.
        """
        values = super(FedoraOpenId, self).get_user_details(response)
        # Store the provided email in cases it's useful down the road.
        values["secondary_email"] = values["email"]
        # Use the significant email.
        values["email"] = "%s@fedoraproject.org" % values["nickname"]
        return values
